import "@/common/styles/forms.sass";
import {useState} from "react";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faArrowLeft, faArrowRightToBracket} from "@fortawesome/free-solid-svg-icons";
import FormInput from "@/common/components/FormInput";

export const JoinForm = ({onSubmit, onBack}) => {
    const [name, setName] = useState("");
    const [roomCode, setRoomCode] = useState("");
    const [errors, setErrors] = useState({});

    const handleSubmit = (e) => {
        e.preventDefault();

        const newErrors = {};
        if (!name.trim()) newErrors.name = "Gib einen Namen an";
        if (!roomCode.trim()) newErrors.roomCode = "Gib einen Raum-Code an";

        if (Object.keys(newErrors).length > 0) {
            setErrors(newErrors);
            return;
        }

        onSubmit(name, roomCode);
    };

    return (
        <div className="form-base join-form">
            <button className="back-button" onClick={onBack}>
                <FontAwesomeIcon icon={faArrowLeft}/>
                <span>Zurück</span>
            </button>

            <h2>Beitreten</h2>

            <form onSubmit={handleSubmit}>
                <FormInput placeholder="Benutzername" value={name} onChange={(e) => setName(e.target.value)}
                           error={errors.name}/>

                <FormInput placeholder="Raum-Code" value={roomCode}
                           onChange={(e) => setRoomCode(e.target.value.toUpperCase())} error={errors.roomCode}
                           maxLength={6}/>

                <button type="submit" className="submit-button join-button">
                    <span>Beitreten</span>
                    <FontAwesomeIcon icon={faArrowRightToBracket}/>
                </button>
            </form>
        </div>
    );
};
